# API Reference

The geqo framework consists of the following components:
- **algorithms**: implementations of more complex operations like QFT
- **core**: used-defined gates, construction of circuits
- **gates**: a collection of basic gates
- **initialization**: operations for setting density matrices and classical bits
- **operations**: measurements and constructions of controlled gates
- **simulators**: several simulators (based on SymPy or NumPy), converter to OpenQASM3
- **utils**: a collection of useful functions
- **visualization**: tools to draw circuits (with LaTex or Matplotlib) and measurement results
